@@ -41,6 +41,9 @@ FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'
 # 引擎识别超时。
 FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'
 
+# 字段值不符合预期
+FAILEDOPERATION_FIELDEXCEPTION = 'FailedOperation.FieldException'
+
 # 文件解码失败
 FAILEDOPERATION_FILEDECODEFAILED = 'FailedOperation.FileDecodeFailed'
 
@@ -50,6 +53,9 @@ FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'
 # 图片分辨率过小或身份证在原图中的占比过小
 FAILEDOPERATION_IDCARDTOOSMALL = 'FailedOperation.IdCardTooSmall'
 
+# 银行卡信息非法。
+FAILEDOPERATION_ILLEGALBANKCARDERROR = 'FailedOperation.IllegalBankCardError'
+
 # 图片模糊。
 FAILEDOPERATION_IMAGEBLUR = 'FailedOperation.ImageBlur'
 
@@ -71,6 +77,12 @@ FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'
 # 图片尺寸过大，请参考输入参数中关于图片大小限制的说明。
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
+# 视读区信息与机读区信息不一致
+FAILEDOPERATION_INCONSISTENCYBETWEENMRZANDVRZ = 'FailedOperation.InconsistencyBetweenMRZAndVRZ'
+
+# 马来西亚证件识别出的邮编长度不正确
+FAILEDOPERATION_INVALIDPOSTALCODELENGTH = 'FailedOperation.InvalidPostalCodeLength'
+
 # 发票数据不一致。温馨提示：新版发票核验接口功能更完整，请尽快切换，如已切换请忽略。
 FAILEDOPERATION_INVOICEMISMATCH = 'FailedOperation.InvoiceMismatch'
 
@@ -86,6 +98,9 @@ FAILEDOPERATION_LICENSEMULTICARDERROR = 'FailedOperation.LicenseMultiCardError'
 # 图片中存在两张及以上同面卡证，请上传卡证单面图片或一正一反双面图片。
 FAILEDOPERATION_MULTICARDERROR = 'FailedOperation.MultiCardError'
 
+# 非银行卡。
+FAILEDOPERATION_NOBANKCARDERROR = 'FailedOperation.NoBankCardError'
+
 # 非营业执照。
 FAILEDOPERATION_NOBIZLICENSE = 'FailedOperation.NoBizLicense'
 
